==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/kdeprint/rlpr/kmrlprmanager.cpp <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#include "kmrlprmanager.h"
#include "kmprinter.h"

#include <qfile.h>
#include <qfileinfo.h>
#include <qtextstream.h>
#include <qmap.h>

#include <kstandarddirs.h>
#include <klocale.h>

KMRlprManager::KMRlprManager(QObject *parent, const QStringList & /*args*/)
    : KMManager(parent)
{
	setHasManagement(true);
	setPrinterOperationMask(KMManager::PrinterCreation|KMManager::PrinterRemoval|KMManager::PrinterTesting);
}

KMRlprManager::~KMRlprManager()
{
}

bool KMRlprManager::createPrinter(KMPrinter *p)
{
	if (p->name().isEmpty())
		setErrorMsg(i18n("Empty printer name."));
	else if (p->option("host").isEmpty())
		setErrorMsg(i18n("Empty host name."));
	else if (p->option("queue").isEmpty())
		setErrorMsg(i18n("Empty queue name."));
	else
	{
		KMPrinter	*pr = new KMPrinter(*p);
		addPrinter(pr);
		savePrinters();
		return true;
	}
	return false;
}

bool KMRlprManager::removePrinter(KMPrinter *p)
{
	if (!m_printers.contains(p))
		setErrorMsg(i18n("Printer not found."));
	else
	{
		m_printers.removeAll(p);
		savePrinters();
		return true;
	}
	return false;
}

bool KMRlprManager::testPrinter(KMPrinter *)
{
	setErrorMsg(i18n("Not implemented yet."));
	return false;
}

void KMRlprManager::listPrinters()
{
	QFileInfo	pfi(printerFile());
	if (pfi.exists() && (!m_checktime.isValid() || m_checktime < pfi.lastModified()))
	{
		loadPrintersConf(pfi.absoluteFilePath());
		m_checktime = pfi.lastModified();
	}
	else
		discardAllPrinters(false);
}

void KMRlprManager::loadPrintersConf(const QString& filename)
{
	QFile	f(filename);
	if (f.exists() && f.open(QIODevice::ReadOnly))
	{
		QTextStream	t(&f);
		QString		line;
		while (!t.atEnd())
		{
			line = t.readLine().trimmed();
			if (line.isEmpty() || line[0] == '#')
				continue;
			QStringList	w = line.split('\t', QString::KeepEmptyParts);
			if (w.count() < 3)
				continue;

			KMPrinter	*printer = new KMPrinter;
			printer->setName(w[0]);
			printer->setPrinterName(w[0]);
			printer->setType(KMPrinter::Printer);
			printer->setOption("host",w[1]);
			printer->setOption("queue",w[2]);
			if (w.count() > 3)
			{
				printer->setDescription(w[3]);
				if (w.count() > 4) printer->setLocation(w[4]);
			}
			printer->setState(KMPrinter::Idle);
			printer->setDevice(QString::fromLatin1("lpd://%1/%2").arg(w[1]).arg(w[2]));

			addPrinter(printer);
		}
	}
}

void KMRlprManager::savePrinters()
{
	savePrintersConf(printerFile());
}

void KMRlprManager::savePrintersConf(const QString& filename)
{
	QFile	f(filename);
	if (f.open(QIODevice::WriteOnly))
	{
		QTextStream	t(&f);
		t << "# File generated by KDE print system. Don't edit by hand." << endl;
		QListIterator<KMPrinter*>	it(m_printers);
		while (it.hasNext())
		{
      KMPrinter *printer(it.next());
			if (!printer->name().isEmpty() && printer->instanceName().isEmpty())
			{
				QString	host = printer->option("host");
				QString	queue = printer->option("queue");
				if (!host.isEmpty() && !queue.isEmpty())
				{
					t << printer->name() << '\t' << host << '\t' << queue;
					t << '\t' << printer->description() << '\t' << printer->location() << endl;
				}
			}
		}
	}
}

QString KMRlprManager::printerFile()
{
	return KStandardDirs::locateLocal("data","kdeprint/printers.conf");
}

==> kde4libs_3.93.0.orig.tar.gz: kde4libs-3.93.0.orig/kdeprint/rlpr/kmrlprmanager.cpp <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 **/

#include "kmrlprmanager.h"
#include "kmprinter.h"

#include <QtCore/QFile>
#include <QtCore/QFileInfo>
#include <QtCore/QTextStream>
#include <QtCore/QMap>

#include <kstandarddirs.h>
#include <klocale.h>

KMRlprManager::KMRlprManager(QObject *parent, const QStringList & /*args*/)
    : KMManager(parent)
{
	setHasManagement(true);
	setPrinterOperationMask(KMManager::PrinterCreation|KMManager::PrinterRemoval|KMManager::PrinterTesting);
}

KMRlprManager::~KMRlprManager()
{
}

bool KMRlprManager::createPrinter(KMPrinter *p)
{
	if (p->name().isEmpty())
		setErrorMsg(i18n("Empty printer name."));
	else if (p->option("host").isEmpty())
		setErrorMsg(i18n("Empty host name."));
	else if (p->option("queue").isEmpty())
		setErrorMsg(i18n("Empty queue name."));
	else
	{
		KMPrinter	*pr = new KMPrinter(*p);
		addPrinter(pr);
		savePrinters();
		return true;
	}
	return false;
}

bool KMRlprManager::removePrinter(KMPrinter *p)
{
	if (!m_printers.contains(p))
		setErrorMsg(i18n("Printer not found."));
	else
	{
		m_printers.removeAll(p);
		savePrinters();
		return true;
	}
	return false;
}

bool KMRlprManager::testPrinter(KMPrinter *)
{
	setErrorMsg(i18n("Not implemented yet."));
	return false;
}

void KMRlprManager::listPrinters()
{
	QFileInfo	pfi(printerFile());
	if (pfi.exists() && (!m_checktime.isValid() || m_checktime < pfi.lastModified()))
	{
		loadPrintersConf(pfi.absoluteFilePath());
		m_checktime = pfi.lastModified();
	}
	else
		discardAllPrinters(false);
}

void KMRlprManager::loadPrintersConf(const QString& filename)
{
	QFile	f(filename);
	if (f.exists() && f.open(QIODevice::ReadOnly))
	{
		QTextStream	t(&f);
		QString		line;
		while (!t.atEnd())
		{
			line = t.readLine().trimmed();
			if (line.isEmpty() || line[0] == '#')
				continue;
			QStringList	w = line.split('\t', QString::KeepEmptyParts);
			if (w.count() < 3)
				continue;

			KMPrinter	*printer = new KMPrinter;
			printer->setName(w[0]);
			printer->setPrinterName(w[0]);
			printer->setType(KMPrinter::Printer);
			printer->setOption("host",w[1]);
			printer->setOption("queue",w[2]);
			if (w.count() > 3)
			{
				printer->setDescription(w[3]);
				if (w.count() > 4) printer->setLocation(w[4]);
			}
			printer->setState(KMPrinter::Idle);
			printer->setDevice(QString::fromLatin1("lpd://%1/%2").arg(w[1]).arg(w[2]));

			addPrinter(printer);
		}
	}
}

void KMRlprManager::savePrinters()
{
	savePrintersConf(printerFile());
}

void KMRlprManager::savePrintersConf(const QString& filename)
{
	QFile	f(filename);
	if (f.open(QIODevice::WriteOnly))
	{
		QTextStream	t(&f);
		t << "# File generated by KDE print system. Don't edit by hand." << endl;
		QListIterator<KMPrinter*>	it(m_printers);
		while (it.hasNext())
		{
      KMPrinter *printer(it.next());
			if (!printer->name().isEmpty() && printer->instanceName().isEmpty())
			{
				QString	host = printer->option("host");
				QString	queue = printer->option("queue");
				if (!host.isEmpty() && !queue.isEmpty())
				{
					t << printer->name() << '\t' << host << '\t' << queue;
					t << '\t' << printer->description() << '\t' << printer->location() << endl;
				}
			}
		}
	}
}

QString KMRlprManager::printerFile()
{
	return KStandardDirs::locateLocal("data","kdeprint/printers.conf");
}
